local AddonName, Addon = ...

local L = Addon.L

local musicTable = {
	[1] = {
		title = L["Play \"Stormwind\""],
		file = "Sound/Music/CityMusic/Stormwind/stormwind_intro-moment.mp3",
		length = 66
	},
	[2] = {
		title = L["Play \"Ironforge\""],
		file = "Sound/Music/CityMusic/Ironforge/IronForge Intro.mp3",
		length = 86
	},
	[3] = {
		title = L["Play \"Night Song\""],
		file = "Sound/Music/Cataclysm/MUS_NightElves_GU01.mp3",
		length = 160
	},
	[4] = {
		title = L["Play \"Gnomeregan\""],
		file = "Sound/Music/event/gnomeregan_event_intro.mp3",
		length = 88
	},
	[5] = {
		title = L["Play \"Exodar\""],
		file = "Sound/Music/ZoneMusic/Azuremyst/AI_ExodarIntro01.mp3",
		length = 82
	},
	[6] = {
		title = L["Play \"Curse of the Worgen\""],
		file = "Sound/Music/Cataclysm/MUS_AllianceHero_UU01.mp3",
		length = 195
	},
	[7] = {
		title = L["Play \"Way of the Monk\""],
		file = "Sound/Music/Pandaria/MUS_50_Monk_Windwalker_A_Hero_02.mp3",
		length = 79
	},
	[8] = {
		title = L["Play Default Garrison Music"],
		file = nil,
		length = nil
	}
}

local function SecondsToMinues(inputSeconds)
	local minutes = math.floor(bit.mod((bit.mod(inputSeconds, 86400)), 3600) / 60)
	local seconds =  math.floor(bit.mod(bit.mod((bit.mod(inputSeconds, 86400)), 3600), 60))
	if seconds < 10 then
		seconds = "0"..seconds
	end
	return minutes..":"..seconds
end

local jukebox

hooksecurefunc(GossipFrame, "Show", function(self)
	if GetGossipText() == L["<The music box crackles and sparks.>"] then
		jukebox = true
	else
		jukebox = nil
	end
end)

hooksecurefunc(GossipFrame, "Hide", function(self)
	jukebox = nil
end)

local lastButton

hooksecurefunc("GossipFrameOptionsUpdate", function(self)
	if jukebox then
		for i = 1, GetNumGossipOptions() do
			_G["GossipTitleButton" .. i]:Hide()
		end
		for i = 1, #musicTable do
			if not _G["GossipOverrideTitleButton"..i] then
				local button = CreateFrame("Button", "GossipOverrideTitleButton"..i, GossipFrame, "GossipTitleButtonTemplate")
				if i == 1 then
					button:SetPoint("TOPLEFT", GossipGreetingText, "BOTTOMLEFT", -10, -20)
				elseif i == #musicTable then
					button:SetPoint("TOPLEFT", lastButton, "BOTTOMLEFT", 0, -18)
				else
					button:SetPoint("TOPLEFT", lastButton, "BOTTOMLEFT", 0, -2)
				end
				if musicTable[i].length then
					button:SetText(musicTable[i].title.." ["..SecondsToMinues(musicTable[i].length).."]")
				else
					button:SetText(musicTable[i].title)
				end
				button:SetScript("OnClick", function(self, button)
					PlaySound("ArmorKitSound")
					StopMusic()
					for j = 1, #musicTable do
						if musicTable[j].length then
							_G["GossipOverrideTitleButton"..j]:SetText(musicTable[j].title.." ["..SecondsToMinues(musicTable[j].length).."]")
						else
							_G["GossipOverrideTitleButton"..j]:SetText(musicTable[j].title)
						end
					end
					if musicTable[i].file then
						PlayMusic(musicTable[i].file)
						if musicTable[i].length then
							self:SetText("|cFF004C99"..musicTable[i].title.." ["..SecondsToMinues(musicTable[i].length).."]".."|r")
						else
							self:SetText("|cFF004C99"..musicTable[i].title.."|r")
						end
					end
					HideUIPanel(GossipFrame)
				end)
				_G["GossipOverrideTitleButton"..i.."GossipIcon"]:SetTexture("Interface\\GossipFrame\\GossipGossipIcon")
				lastButton = button:GetName()
			end
			if _G["GossipOverrideTitleButton"..i] then
				_G["GossipOverrideTitleButton"..i]:Show()
			end
		end
	else
		for i = 1, #musicTable do
			if _G["GossipOverrideTitleButton"..i] then
				_G["GossipOverrideTitleButton"..i]:Hide()
			end
		end
	end
end)